/// <reference types="node" />
import { Sql } from 'postgres';
import ReadStream from './ReadStream';
import WriteStream from './WriteStream';
declare enum SEEK_REF {
    SEEK_SET = 0,
    SEEK_CUR = 1,
    SEEK_END = 2
}
/**
 * Represents an opened large object.
 * @constructor
 * @exports postgres-large-object/lib/LargeObject
 */
declare class LargeObject {
    /**
     * A seek from the beginning of a object
     * @constant {number}
     */
    static SEEK_SET: SEEK_REF;
    /**
     * A seek from the current position
     * @constant {number}
     */
    static SEEK_CUR: SEEK_REF;
    /**
     * A seek from the end of a object
     * @constant {number}
     */
    static SEEK_END: SEEK_REF;
    oid: number;
    private _sql;
    private _fd;
    constructor(sql: Sql<never>, oid: number, fd: number);
    /** Closes this large object.
     *  You should no longer call any methods on this object.
     * @returns {Promise}
     */
    closeAsync: () => Promise<void>;
    /** @callback module:postgres-large-object/lib/LargeObject~closeCallback
     * @param {?Error} error If set, an error occurred.
     */
    /** Closes this large object.
     *  You should no longer call any methods on this object.
     * @param {module:postgres-large-object/lib/LargeObject~closeCallback} [callback]
     */
    close: (callback: (err: NodeJS.ErrnoException) => void) => void;
    /** Reads some data from the large object.
     * @param {Number} length How many bytes to read
     * @returns {Promise.<Buffer>} The binary data that was read.
     *          If the length of this buffer is less than the supplied
     *          length param, there is no more data to be read.
     */
    readAsync: (length: number) => Promise<Buffer>;
    /** @callback module:postgres-large-object/lib/LargeObject~readCallback
     * @param {?Error} error If set, an error occurred.
     * @param {Buffer} data The binary data that was read.
     *        If the length of this buffer is less than the supplied
     *        length param, there is no more data to be read.
     */
    /** Reads some data from the large object.
     * @param {Number} length How many bytes to read
     * @param {module:postgres-large-object/lib/LargeObject~readCallback} callback
     */
    read: (arg1: number, callback: (err: NodeJS.ErrnoException, result: Buffer) => void) => void;
    /** Writes some data to the large object.
     * @param {Buffer} buffer data to write
     * @returns {Promise}
     */
    writeAsync: (buffer: Buffer) => Promise<void>;
    /** @callback module:postgres-large-object/lib/LargeObject~writeCallback
     * @param {?Error} error If set, an error occurred.
     */
    /** Writes some data to the large object.
     * @param {Buffer} buffer data to write
     * @param {module:postgres-large-object/lib/LargeObject~writeCallback} [callback]
     */
    write: (arg1: Buffer, callback: (err: NodeJS.ErrnoException) => void) => void;
    /** Sets the position within the large object.
     * Beware floating point rounding with values greater than 2^53 (8192 TiB)
     * @param {Number} position
     * @param {Number} ref One of SEEK_SET, SEEK_CUR, SEEK_END
     * @returns {Promise.<number>} The new position
     */
    seekAsync: (position: number, ref: SEEK_REF) => Promise<number>;
    /** @callback module:postgres-large-object/lib/LargeObject~seekCallback
     * @param {?Error} error If set, an error occurred.
     * @param {Number} position The new position
     */
    /** Sets the position within the large object.
     * Beware floating point rounding with values greater than 2^53 (8192 TiB)
     * @param {Number} position
     * @param {Number} ref One of SEEK_SET, SEEK_CUR, SEEK_END
     * @param {module:postgres-large-object/lib/LargeObject~seekCallback} [callback]
     */
    seek: (arg1: number, arg2: SEEK_REF, callback: (err: NodeJS.ErrnoException | null, result: number) => void) => void;
    /** Retrieves the current position within the large object.
     * Beware floating point rounding with values greater than 2^53 (8192 TiB)
     * @returns {Promise.<number>}
     */
    tellAsync: () => Promise<number>;
    /** @callback module:postgres-large-object/lib/LargeObject~tellCallback
     * @param {?Error} error If set, an error occurred.
     * @param {Number} position The position
     */
    /** Retrieves the current position within the large object.
     * Beware floating point rounding with values greater than 2^53 (8192 TiB)
     * @param {module:postgres-large-object/lib/LargeObject~tellCallback} callback
     */
    tell: (callback: (err: NodeJS.ErrnoException, result: number) => void) => void;
    /** Find the total size of the large object.
     * @returns {Promise.<number>}
     */
    sizeAsync: () => Promise<number>;
    /** @callback module:postgres-large-object/lib/LargeObject~sizeCallback
     * @param {?Error} error If set, an error occurred.
     * @param {Number} size Object size in bytes
     */
    /** Find the total size of the large object.
     * @param {module:postgres-large-object/lib/LargeObject~sizeCallback} callback
     */
    size: (callback: (err: NodeJS.ErrnoException, result: number) => void) => void;
    /** Truncates the large object to the given length in bytes.
     * If the number of bytes is larger than the current large
     * object length, the large object will be filled with zero
     * bytes.  This method does not modify the current file offset.
     * @param {Number} length
     * @returns {Promise}
     */
    truncateAsync: (length: number) => Promise<void>;
    /** @callback module:postgres-large-object/lib/LargeObject~truncateCallback
     * @param {?Error} error If set, an error occurred.
     */
    /** Truncates the large object to the given length in bytes.
     * If the number of bytes is larger than the current large
     * object length, the large object will be filled with zero
     * bytes.  This method does not modify the current file offset.
     * @param {Number} length
     * @param {module:postgres-large-object/lib/LargeObject~truncateCallback} [callback]
     */
    truncate: (arg1: number, callback: (err: NodeJS.ErrnoException) => void) => void;
    /** Return a stream to read this large object.
     * Call this within a transaction block.
     * @param {Number} [bufferSize=16384] A larger buffer size will
     * require more memory on both the server and client, however it will make
     * transfers faster because there is less overhead (less read calls to the server).
     * his overhead is most noticeable on high latency connections because each
     * ransfered chunk will incur at least RTT of additional transfer time.
     * @returns {module:postgres-large-object/lib/ReadStream}
     */
    getReadableStream: (bufferSize?: number) => ReadStream;
    /** Return a stream to write to this large object.
     * Call this within a transaction block.
     * @param {Number} [bufferSize=16384] A larger buffer size will
     * require more memory on both the server and client, however it will make
     * transfers faster because there is less overhead (less read calls to the server).
     * his overhead is most noticeable on high latency connections because each
     * ransfered chunk will incur at least RTT of additional transfer time.
     * @returns {module:postgres-large-object/lib/WriteStream}
     */
    getWritableStream: (bufferSize?: number) => WriteStream;
}
export = LargeObject;
